import os
import glob
import platform
from InquirerPy import prompt
from fire import Fire
from .consts import ENV_KEY, LOCATIONS, VARIATIONS, DEFAULT_VARIATION

## 環境変数を表示
def show_status():
    print(f'{ENV_KEY}: {os.getenv(ENV_KEY)}')


## プロフィールディレクトリを環境変数に設定
def set_profile_dir():
    variation = get_variation()
    profile_dir = os.getenv(ENV_KEY)
    profile_dirs = get_profile_dirs(variation)
    questions = [
        {
            "type": "list",
            "message": f"Select an profile directory [{variation}]:",
            "choices": profile_dirs,
            "default": profile_dir,
        },
    ]
    profile_dir = prompt(questions)
    os.environ[ENV_KEY] = profile_dir[0]
    show_status()


## ブラウザバリエーションを取得
def get_variation():
    variation = DEFAULT_VARIATION
    questions = [
        {
            "type": "list",
            "message": "Select an bowser variation:",
            "choices": VARIATIONS,
            "default": variation,
        },
    ]
    variation = prompt(questions)
    return variation[0]

## プロフィールディレクトリ一覧の取得
def get_profile_dirs(variation=DEFAULT_VARIATION)->str:
    platform_type = (lambda v: v if v in ['Darwin', 'Windows'] else 'Linux')(platform.system())
    home_dir = os.getenv('LOCALAPPDATA') if platform_type == 'Windows' else os.path.expanduser('~')
    
    profile_home_dir = home_dir + LOCATIONS[platform_type][variation]
    profile_dirs = list(filter(
      lambda f : f != 'System Profile' and os.path.exists(os.path.join(f, 'Preferences')), 
      glob.glob(os.path.join(profile_home_dir,'*'))
    ))
    return profile_dirs



class Command:
    def status(self):
        show_status()
    def setup(self):
        set_profile_dir()

if __name__ == '__main__':
    #set_profile_dir()
    Fire(Command)


import os
from selenium import webdriver
import chromedriver_autoinstaller
from selenium.webdriver.chrome.options import Options
from .consts import ENV_KEY, USER_AGENT


def chrofile(headless:bool=True, size='1920,1200')->webdriver.Chrome:
  options = Options()

  profile_dir = os.getenv(ENV_KEY)
  if profile_dir and os.path.exists(profile_dir):
    options.add_argument(f'--profile-directory={os.path.basename(profile_dir)}')
    options.add_argument(f'--user-data-dir={os.path.dirname(profile_dir)}')
  if headless: options.add_argument('--headless')
  
  options.add_argument(f'user-agent={USER_AGENT}')
  options.add_argument(f'--window-size={size}')

  chromedriver_autoinstaller.install()
  return webdriver.Chrome(options=options)





VARIATIONS = ['CHROME', 'CHROME_CANARY', 'CHROMIUM']
DEFAULT_VARIATION = VARIATIONS[0]

USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36'


LOCATIONS = {
    # macOS
    'Darwin': {
        'CHROME': '/Library/Application Support/Google/Chrome',
        'CHROME_CANARY': '/Library/Application Support/Google/Chrome Canary',
        'CHROMIUM': '/Library/Application Support/Chromium'
    },
    'Windows': {
        'CHROME': '\\Google\\Chrome\\User Data',
        'CHROME_CANARY': '\\Google\\Chrome SxS\\User Data',
        'CHROMIUM': '\\Chromium\\User Data'
    },
    'Linux':{ 
        'CHROME': '/.config/google-chrome',
        'CHROME_CANARY': '/.config/google-chrome-beta',
        'CHROMIUM': '/.config/chromium'
    }
}

ENV_KEY = 'CHROFILE_PROFILE_DIR'


import re
from time import sleep
from chrofile.core import chrofile
from lxml import html 
from pydash.objects import get
from selenium.webdriver.common.by import By

if __name__ == "__main__":
  store_id = 'twisnu2727'
  driver = None
  records = []
  start_urls = [f'https://www.tokopedia.com/{store_id}/etalase/sold']
  try:
    driver = chrofile()
    driver.get(start_urls[0])
    while True:
      sleep(3)
      driver.execute_script("window.scrollTo(0, document.body.scrollHeight)")
      sleep(2)
      source = html.fromstring(driver.page_source) 
      for product in source.xpath("//div[contains(@class, 'prd_container-card')]"):
        records.append({
          'url': get(product.xpath(".//a[contains(@class, 'pcv3__info-content')]/@href"), '[0]', None),
          'store_id': store_id,
          'image': get(product.xpath(".//img[@data-testid='imgProduct']/@src"), '[0]', None),
          'name': get(product.xpath(".//div[contains(@class, 'prd_link-product-name')]/text()"), '[0]', ''),
          'price': int(re.sub(r'\D', '', get(product.xpath(".//div[contains(@class, 'prd_link-product-price')]/text()"), '[0]', None)) or '0'),
          'currency_id': 'rp',
          'rate': float(get(product.xpath(".//span[contains(@class, 'prd_rating-average-text')]/text()"), '[0]', None) or '0'),
          'sold': int(re.sub(r'\D', '', get(product.xpath(".//span[contains(@class, 'prd_label-integrity')]/text()"), '[0]', None)) or '0')
        })
      
      next_button = get(driver.find_elements(By.XPATH, ("//a[@data-testid='btnShopProductPageNext']")), '[0]', None)
      
      if not next_button : break
      next_button.click()
      driver.execute_script("window.scrollTo(0, 0)")
      
    print(records)
  except Exception as e:
    print(e)
  finally:
    if driver: driver.quit()


from . import *
__copyright__    = 'Copyright (C) 2021 inovue'
__version__      = '1.0.0'
__license__      = 'BSD-3-Clause'
__author__       = 'inovue'
__author_email__ = 'info@inovue.com'
__url__          = 'http://github.com/inovue/chrofile'

#__all__ = []